@@ -17,13 +17,13 @@ from SciDataTool.GUI.WVectorSelector.WVectorSelector import WVectorSelector
 class Ui_WPlotManager(object):
     def setupUi(self, WPlotManager):
         if not WPlotManager.objectName():
-            WPlotManager.setObjectName(u"WPlotManager")
+            WPlotManager.setObjectName("WPlotManager")
         WPlotManager.resize(376, 683)
         self.verticalLayout = QVBoxLayout(WPlotManager)
-        self.verticalLayout.setObjectName(u"verticalLayout")
+        self.verticalLayout.setObjectName("verticalLayout")
         self.verticalLayout.setContentsMargins(0, 0, 0, 0)
         self.w_vect_selector = WVectorSelector(WPlotManager)
-        self.w_vect_selector.setObjectName(u"w_vect_selector")
+        self.w_vect_selector.setObjectName("w_vect_selector")
         sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -37,7 +37,7 @@ class Ui_WPlotManager(object):
         self.verticalLayout.addWidget(self.w_vect_selector)
 
         self.w_axis_manager = WAxisManager(WPlotManager)
-        self.w_axis_manager.setObjectName(u"w_axis_manager")
+        self.w_axis_manager.setObjectName("w_axis_manager")
         sizePolicy.setHeightForWidth(
             self.w_axis_manager.sizePolicy().hasHeightForWidth()
         )
@@ -48,7 +48,7 @@ class Ui_WPlotManager(object):
         self.verticalLayout.addWidget(self.w_axis_manager)
 
         self.w_range = WDataRange(WPlotManager)
-        self.w_range.setObjectName(u"w_range")
+        self.w_range.setObjectName("w_range")
         sizePolicy.setHeightForWidth(self.w_range.sizePolicy().hasHeightForWidth())
         self.w_range.setSizePolicy(sizePolicy)
         self.w_range.setMinimumSize(QSize(0, 0))
@@ -58,7 +58,7 @@ class Ui_WPlotManager(object):
 
         self.gridLayout_2 = QGridLayout()
         self.gridLayout_2.setSpacing(5)
-        self.gridLayout_2.setObjectName(u"gridLayout_2")
+        self.gridLayout_2.setObjectName("gridLayout_2")
         self.gridLayout_2.setContentsMargins(11, 11, 10, 11)
         self.horizontalSpacer = QSpacerItem(
             40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
@@ -67,7 +67,7 @@ class Ui_WPlotManager(object):
         self.gridLayout_2.addItem(self.horizontalSpacer, 0, 0, 1, 1)
 
         self.b_export = QPushButton(WPlotManager)
-        self.b_export.setObjectName(u"b_export")
+        self.b_export.setObjectName("b_export")
         sizePolicy.setHeightForWidth(self.b_export.sizePolicy().hasHeightForWidth())
         self.b_export.setSizePolicy(sizePolicy)
         self.b_export.setMinimumSize(QSize(0, 0))
@@ -91,10 +91,10 @@ class Ui_WPlotManager(object):
 
     def retranslateUi(self, WPlotManager):
         WPlotManager.setWindowTitle(
-            QCoreApplication.translate("WPlotManager", u"WPlotManager", None)
+            QCoreApplication.translate("WPlotManager", "WPlotManager", None)
         )
         self.b_export.setText(
-            QCoreApplication.translate("WPlotManager", u"Export", None)
+            QCoreApplication.translate("WPlotManager", "Export", None)
         )
 
     # retranslateUi
